@@ -1,6 +1,6 @@
 # This script configures QScintilla for PyQt v3 and/or v4.
 #
-# Copyright (c) 2016 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2017 Riverbank Computing Limited <info@riverbankcomputing.com>
 # 
 # This file is part of QScintilla.
 # 
@@ -55,7 +55,7 @@ else:
 
 # This must be kept in sync with Python/configure.py, qscintilla.pro,
 # example-Qt4Qt5/application.pro and designer-Qt4Qt5/designer.pro.
-QSCI_API_MAJOR = 12
+QSCI_API_MAJOR = 13
 
 
 # Initialise the globals.
@@ -77,7 +77,7 @@ def create_optparser():
         setattr(parser.values, option.dest, os.path.abspath(value))
 
     p = optparse.OptionParser(usage="python %prog [options]",
-            version="2.9.4")
+            version="2.10")
 
     p.add_option("-a", "--apidir", action="callback", default=None,
             type="string", metavar="DIR", dest="qscidir",
@@ -177,8 +177,8 @@ def check_qscintilla():
             # Because we include the Python bindings with the C++ code we can
             # reasonably force the same version to be used and not bother about
             # versioning.
-            if sciversstr != "2.9.4":
-                sipconfig.error("QScintilla %s is being used but the Python bindings 2.9.4 are being built.  Please use matching versions." % sciversstr)
+            if sciversstr != "2.10":
+                sipconfig.error("QScintilla %s is being used but the Python bindings 2.10 are being built.  Please use matching versions." % sciversstr)
 
             sipconfig.inform("QScintilla %s is being used." % sciversstr)
         else:
