@@ -40,7 +40,7 @@ import sys
 
 # This must be kept in sync with Python/configure-old.py, qscintilla.pro,
 # example-Qt4Qt5/application.pro and designer-Qt4Qt5/designer.pro.
-QSCI_API_MAJOR = 12
+QSCI_API_MAJOR = 13
 
 
 class ModuleConfiguration(object):
@@ -60,7 +60,7 @@ class ModuleConfiguration(object):
 
     # The version of the module as a string.  Set it to None if you don't
     # provide version information.
-    version = '2.9.4'
+    version = '2.10'
 
     # Set if a configuration script is provided that handles versions of PyQt4
     # prior to v4.10 (i.e. versions where the pyqtconfig.py module is
@@ -222,7 +222,7 @@ class ModuleConfiguration(object):
         if lib_dir is None:
             lib_dir = target_configuration.qt_lib_dir
 
-        if not glob.glob(os.path.join(lib_dir, '*qscintilla2*')):
+        if not glob.glob(os.path.join(lib_dir, '*qscintilla2_qt*')):
             error(
                     "The QScintilla library could not be found in %s. If "
                     "QScintilla is installed then use the --qsci-libdir "
@@ -330,7 +330,9 @@ class ModuleConfiguration(object):
             lib_dir = target_configuration.qt_lib_dir
 
         return os.path.join(lib_dir,
-                'libqscintilla2.%s.dylib' % QSCI_API_MAJOR)
+                'libqscintilla2_qt%s.%s.dylib' % (
+                        target_configuration.qt_version_str[0],
+                        QSCI_API_MAJOR))
 
 
 ###############################################################################
@@ -639,6 +641,7 @@ class _HostPythonConfiguration:
         self.inc_dir = sysconfig.get_python_inc()
         self.venv_inc_dir = sysconfig.get_python_inc(prefix=sys.prefix)
         self.module_dir = sysconfig.get_python_lib(plat_specific=1)
+        self.debug = hasattr(sys, 'gettotalrefcount')
 
         if sys.platform == 'win32':
             self.data_dir = sys.prefix
@@ -688,6 +691,7 @@ class _TargetConfiguration:
 
         # Values based on the host Python configuration.
         py_config = _HostPythonConfiguration()
+        self.py_debug = py_config.debug
         self.py_platform = py_config.platform
         self.py_version = py_config.version
         self.py_module_dir = py_config.module_dir
@@ -714,12 +718,14 @@ class _TargetConfiguration:
             self.qmake_spec = ''
 
         # Remaining values.
+        self.debug = False
         self.pyqt_sip_flags = None
         self.pyqt_version_str = ''
         self.qmake = self._find_exe('qmake')
         self.qt_version_str = ''
         self.sip = self._find_exe('sip5', 'sip')
         self.sip_version = None
+        self.sip_version_str = None
         self.sysroot = ''
         self.stubs_dir = ''
 
@@ -960,6 +966,21 @@ class _TargetConfiguration:
         configuration.  opts are the command line options.
         """
 
+        # On Windows the interpreter must be a debug build if a debug version
+        # is to be built and vice versa.
+        if sys.platform == 'win32':
+            if opts.debug:
+                if not self.py_debug:
+                    error(
+                            "A debug version of Python must be used when "
+                            "--debug is specified.")
+            elif self.py_debug:
+                error(
+                        "--debug must be specified when a debug version of "
+                        "Python is used.")
+
+        self.debug = opts.debug
+
         # Get the system root.
         if opts.sysroot is not None:
             self.sysroot = opts.sysroot
@@ -1218,6 +1239,12 @@ def _inform_user(target_config, pkg_config):
     inform("%s will be installed in %s." %
             (pkg_name, target_config.module_dir))
 
+    if target_config.debug:
+        inform("A debug version of %s will be built." % pkg_name)
+
+    if target_config.py_debug:
+        inform("A debug build of Python is being used.")
+
     if target_config.pyqt_version_str != '':
         inform("PyQt %s is being used." % target_config.pyqt_version_str)
     else:
@@ -1229,7 +1256,7 @@ def _inform_user(target_config, pkg_config):
     if target_config.sysroot != '':
         inform("The system root directory is %s." % target_config.sysroot)
 
-    inform("sip %s is being used." % target_config.sip_version)
+    inform("sip %s is being used." % target_config.sip_version_str)
     inform("The sip executable is %s." % target_config.sip)
 
     if target_config.prot_is_public:
@@ -1264,6 +1291,10 @@ def _generate_code(target_config, opts, pkg_config, module_config):
     # Build the SIP command line.
     argv = [quote(target_config.sip)]
 
+    # Tell SIP if this is a debug build of Python (SIP v4.19.1 and later).
+    if target_config.sip_version >= 0x041301 and target_config.py_debug:
+        argv.append('-D')
+
     # Add the module-specific flags.
     argv.extend(pkg_config.get_sip_flags(target_config))
 
@@ -1378,7 +1409,7 @@ def _generate_pro(target_config, opts, module_config):
     if qt:
         pro.write('QT += %s\n' % qt)
 
-    pro.write('CONFIG += %s\n' % ('debug' if opts.debug else 'release'))
+    pro.write('CONFIG += %s\n' % ('debug' if target_config.debug else 'release'))
     pro.write('CONFIG += %s\n' % ('staticlib' if opts.static else 'plugin'))
 
     config = qmake_config.get('CONFIG')
@@ -1644,7 +1675,9 @@ def _check_sip(target_config, pkg_config):
 
     pipe.close()
 
-    if '.dev' not in version_str and 'snapshot' not in version_str:
+    if '.dev' in version_str or 'snapshot' in version_str:
+        version = 0
+    else:
         version = version_from_string(version_str)
         if version is None:
             error(
@@ -1659,7 +1692,8 @@ def _check_sip(target_config, pkg_config):
                         "This version of %s requires sip %s or later." %
                                 (pkg_config.descriptive_name, min_sip_version))
 
-    target_config.sip_version = version_str
+    target_config.sip_version = version
+    target_config.sip_version_str = version_str
 
 
 def _main(argv, pkg_config):
